#
# spec file for package deepin-movie
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover 0_1

Name:           deepin-movie
Version:        3.2.24.3
Release:        lp152.1.5
Summary:        Deepin Video Players
License:        GPL-3.0-or-later AND OpenSSL
Group:          Productivity/Multimedia/Video/Players
URL:            https://github.com/linuxdeepin/deepin-movie-reborn
Source:         https://github.com/linuxdeepin/deepin-movie-reborn/archive/%{version}/%{name}-reborn-%{version}.tar.gz
# PATCH-FIX-UPSTEAM deepin-movie-reborn-add-pkgconfig-check.patch hillwood@opensuse.org - fix lost pkgconfig check
Patch0:         deepin-movie-reborn-add-pkgconfig-check.patch
# PATCH-FIX-UPSTEAM deepin-movie-add-qthelper.patch hillwood@opensuse.org
# qthelper.hpp was removed from mpv project, move this api in this project.
Patch1:         deepin-movie-add-qthelper.patch
BuildRequires:  dtkcore
BuildRequires:  fdupes
BuildRequires:  glslang-devel
BuildRequires:  cmake(Qt5LinguistTools)
BuildRequires:  pkgconfig(Qt5Concurrent)
BuildRequires:  pkgconfig(Qt5DBus)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5Sql)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5X11Extras)
BuildRequires:  pkgconfig(dtkcore)
BuildRequires:  pkgconfig(dtkwidget)
BuildRequires:  pkgconfig(dvdnav)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libavresample)
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  pkgconfig(libffmpegthumbnailer)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(libpulse-simple)
BuildRequires:  pkgconfig(mpv)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(xcb-aux)
BuildRequires:  pkgconfig(xcb-ewmh)
BuildRequires:  pkgconfig(xcb-proto)
BuildRequires:  pkgconfig(xcb-shape)
BuildRequires:  pkgconfig(xcb-util)
BuildRequires:  pkgconfig(xtst)
Recommends:     %{name}-lang
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
The default media player for Deepin. QML is used to build its
graphical interface, combined with QtAV as its multimedia backend.

%package -n libdmr%{sover}
Summary:        Deepin Video Players
Group:          System/Libraries

%description -n libdmr%{sover}
libdmr is a library for accessing the Direct Rendering Manager on Linux, BSD and
other operating systems that support the ioctl interface, and for chipsets with
DRM memory manager, support for tracking relocations and buffers. libdmr is a
low-level library, typically used by graphics drivers such as the Mesa DRI and X
drivers.

%package devel
Summary:        Development tools for deepin movie
Group:          Development/Languages/C and C++
Requires:       libdmr%{sover} = %{version}

%description devel
The deepin-movie-devel package contains the header files and developer docs for
deepin movie.

%lang_package

%prep
%setup -q -n %{name}-reborn-%{version}
%patch0 -p1
%patch1 -p1
sed -i 's,/usr/lib/dtk2/dtk-settings-tool,/usr/bin/dtk-settings-tool,g' src/CMakeLists.txt

%build
%cmake -DCMAKE_BUILD_TYPE=Release
make %{?_smp_mflags}

%install
%cmake_install

%fdupes %{buildroot}

%post -n libdmr%{sover} -p /sbin/ldconfig

%postun -n libdmr%{sover} -p /sbin/ldconfig

%files
%defattr(-,root,root,-)
%doc README.md HACKING.md CHANGELOG.md
%license LICENSE LICENSE.OpenSSL
%{_bindir}/%{name}
%{_datadir}/%{name}
%exclude %{_datadir}/%{name}/translations
%{_datadir}/applications/%{name}.desktop
%dir %{_datadir}/icons/hicolor/scalable
%dir %{_datadir}/icons/hicolor/scalable/apps
%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg

%files -n libdmr%{sover}
%defattr(-,root,root)
%{_libdir}/libdmr.so.*

%files devel
%defattr(-,root,root)
%{_libdir}/libdmr.so
%{_libdir}/pkgconfig/*.pc
%{_includedir}/libdmr

%files lang
%defattr(-,root,root)
%{_datadir}/%{name}/translations

%changelog
* Fri Mar 20 2020 Hillwood Yang <hillwood@opensuse.org>
- Add deepin-movie-add-qthelper.patch.
  qthelper.hpp was removed from mpv project, move this api in this project
* Sun Aug  4 2019 Hillwood Yang <hillwood@opensuse.org>
- Update version to 3.2.24.3
  * Fix dtk-settings tool path
  * Update translations
  * Support Qt 5.13.0, drop Fix-build-on-Qt-5_13_0.patch
  * fix no-return-in-nonvoid-function check, drop
    no-return-in-nonvoid-function.patch
* Tue Jul  9 2019 Hillwood Yang <hillwood@opensuse.org>
- Update version to 3.2.24
  * Fix card0 may not enabled/usable
  * Should free xcb_query_pointer_reply return pointer
  * workaround for QTBUG-76114.
  * Missing settings item added. Fix crash on file open.
  * Thumbnail previewer caused dock show up
  * Remember last opened path
  * Drag and drop to load subtitle
  * Fix buttons not shwon in mini mode on arm64 platform
  * Fix can not toggle mini mode when window maximized
  * Fix don't sleep while playing
  * New subtitle font style
- Fix build on Qt 5.13.0, add Fix-build-on-Qt-5_13_0.patch
- Add OpenSSL license
* Sat Mar 16 2019 Jan Engelhardt <jengelh@inai.de>
- Ensure neutrality and accuracy of description.
* Tue Jan  8 2019 hillwood@opensuse.org
- Split development package.
* Thu Dec 20 2018 hillwood@opensuse.org
- Update version to 3.2.17
  * Fix the window point not follow touch point on touch screen and
    enable hi-DPI
  * remove application name in titlebar
  * set the generic name to "Movie"
  * support auto translate the dekstop file
  * Deepin vendor support
  * support the recent file spec
  * support touch move window
  * no transifex
  * Fix build error with libavresample deprecated
  * Fix crash when press F1
  * refactor: use DApplication::handleHelpAction to open help document
  * remove the TitleBar right margin
  * fix(libdmr): bypass sub saving and compilation
  * add frame-by-frame navigation support
- Add no-return-in-nonvoid-function.patch, fix no-return-in-nonvoid-function
  check.
* Fri Dec  1 2017 hillwood@opensuse.org
- Update to 3.0.1
  * Use vaapi_egl opengl interop when possible
  * Support build with DTK_DMAN_PORTAL
  * Support dman activation from flatpak env
  * Make play state button clickable
  * Hide titlebar in fullscreen playback
  * Render HiDPI texture by QImageReader
  * Use QImageReader to render HiDPI images
  * Correct shape mask in non-composited mode
  * Make sub font size approximate pixel size
  * Update playlist geometry under flatpak env
  Fix bugs:
  * Check cookie before inhibit
  * Cookie should be unsigned int
  * Check and do UnInhibit when window closed
  * Pixmap take device ratio into account
  * Make toolbox more transparent
  * Scale fbo according to devicePixelRatio
  * Honor devicePixelRatio for pixmap rendering
  * Basic hdpi texture adaption
  * Support flatpak
  * Respect devicePixelRatio when move
  * Improve 4k playback by disable opengl-hq
  * Update svgs and more QImageReader migration
  * Potential crash when closing a smb shared video
- Split language package.
- Add deepin-movie-reborn-add-pkgconfig-check.patch, fix pkg check
* Thu Nov  2 2017 hillwood@opensuse.org
- Update to 2.9.94
  * Migrate to QML.
* Thu Sep 28 2017 hillwood@opensuse.org
- Update to 2.2.15
  * Not showing resize visual while resizing
  * Fix a typo: useage -> usage
  * Translate desktop file
  * remove deepin-util depend in control
* Mon Feb 20 2017 hillwood@opensuse.org
- Update to 2.2.11
  * Fix crash on opening empty folder.
  * Fix crash on Qt5.6
  * Update window buttons
  * Cherry pick some bugfixes from release/2.2.2
  * Base on QtAV.
* Sun Oct 18 2015 i@marguerite.su
- add patch: deepin-movie-QJSValue-not-iterable.patch
  * fix "TypeError: 'QJSValue' object is not iterable"
  * https://github.com/linuxdeepin/deepin-movie/issues/11
* Mon Aug  3 2015 i@marguerite.su
- initial version 2.2.2+git20150504.8344897
